summaryrefslogtreecommitdiff
path: root/src/lib/util.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-04-02 00:03:45 +0100
committerCarl Hetherington <cth@carlh.net>2013-04-02 00:03:45 +0100
commitfff7a8232b18ce6191e60ba911c29b64b9063d4d (patch)
tree3c61d950f341717c7b2478c110c9f1f6c3bef05a /src/lib/util.cc
parent6809fdcbf8c65afe3c986b0e2b430d55ce7b124c (diff)
Various bits.
Diffstat (limited to 'src/lib/util.cc')
-rw-r--r--src/lib/util.cc14
1 files changed, 2 insertions, 12 deletions
diff --git a/src/lib/util.cc b/src/lib/util.cc
index 1c020875a..e0de82c64 100644
--- a/src/lib/util.cc
+++ b/src/lib/util.cc
@@ -476,16 +476,6 @@ dcp_audio_sample_rate (int fs)
return 96000;
}
-bool operator== (Crop const & a, Crop const & b)
-{
- return (a.left == b.left && a.right == b.right && a.top == b.top && a.bottom == b.bottom);
-}
-
-bool operator!= (Crop const & a, Crop const & b)
-{
- return !(a == b);
-}
-
/** @param index Colour LUT index.
* @return Human-readable name.
*/
@@ -867,13 +857,13 @@ ensure_ui_thread ()
assert (this_thread::get_id() == ui_thread);
}
/** @param v Source video frame.
* @param audio_sample_rate Source audio sample rate.
* @param frames_per_second Number of video frames per second.
* @return Equivalent number of audio frames for `v'.
*/
int64_t
-video_frames_to_audio_frames (SourceFrame v, float audio_sample_rate, float frames_per_second)
+video_frames_to_audio_frames (ContentVideoFrame v, float audio_sample_rate, float frames_per_second)
{
return ((int64_t) v * audio_sample_rate / frames_per_second);
}
@@ -867,13 +857,13 @@ ensure_ui_thread ()
assert (this_thread::get_id() == ui_thread);
}
-/** @param v Source video frame.
+/** @param v Content video frame.
* @param audio_sample_rate Source audio sample rate.
* @param frames_per_second Number of video frames per second.